@@ -32,7 +32,6 @@ import (
 	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha2"
 	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha3"
 	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha4"
-	"github.com/k3d-io/k3d/v5/pkg/config/v1alpha5"
 	defaultConfig "github.com/k3d-io/k3d/v5/pkg/config/v1alpha5"
 
 	types "github.com/k3d-io/k3d/v5/pkg/config/types"
@@ -44,7 +43,7 @@ var Schemas = map[string]string{
 	v1alpha2.ApiVersion: v1alpha2.JSONSchema,
 	v1alpha3.ApiVersion: v1alpha3.JSONSchema,
 	v1alpha4.ApiVersion: v1alpha4.JSONSchema,
-	v1alpha5.ApiVersion: v1alpha5.JSONSchema,
+	defaultConfig.ApiVersion: defaultConfig.JSONSchema,
 }
 
 func GetSchemaByVersion(apiVersion string) ([]byte, error) {
@@ -72,7 +71,7 @@ func FromViper(config *viper.Viper) (types.Config, error) {
 	case "k3d.io/v1alpha4":
 		cfg, err = v1alpha4.GetConfigByKind(kind)
 	case "k3d.io/v1alpha5":
-		cfg, err = v1alpha5.GetConfigByKind(kind)
+		cfg, err = defaultConfig.GetConfigByKind(kind)
 	case "":
 		cfg, err = defaultConfig.GetConfigByKind(kind)
 	default:
@@ -96,8 +95,8 @@ func getMigrations(version string) map[string]func(types.Config) (types.Config,
 		return v1alpha3.Migrations
 	case v1alpha4.ApiVersion:
 		return v1alpha4.Migrations
-	case v1alpha5.ApiVersion:
-		return v1alpha5.Migrations
+	case defaultConfig.ApiVersion:
+		return defaultConfig.Migrations
 	default:
 		return nil
 	}
