@@ -1,5 +1,5 @@
 /*
-Copyright © 2020-2021 The k3d Author(s)
+Copyright © 2020-2022 The k3d Author(s)
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -37,3 +37,8 @@ var (
 
 // Container Filesystem Errors
 var ErrRuntimeFileNotFound = errors.New("file not found")
+
+// Runtime Volume Errors
+var (
+	ErrRuntimeVolumeNotExists = errors.New("volume does not exist")
+)
