@@ -24,7 +24,7 @@ package types
 import (
 	"time"
 
-	l "github.com/rancher/k3d/v5/pkg/logger"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
 )
 
 // NodeWaitForLogMessageRestartWarnTime is the time after which to warn about a restarting container
